"use strict";
/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
Object.defineProperty(exports, "__esModule", { value: true });
exports.InMemoryDocument = void 0;
const vscode_languageserver_textdocument_1 = require("vscode-languageserver-textdocument");
const position_1 = require("./types/position");
class InMemoryDocument {
    constructor(uri, contents, version = 0) {
        this.uri = uri;
        this.version = version;
        this._doc = vscode_languageserver_textdocument_1.TextDocument.create(uri.toString(), 'markdown', version, contents);
    }
    get lineCount() {
        return this._doc.lineCount;
    }
    lineAt(index) {
        if (!this.lines) {
            this.lines = this._doc.getText().split(/\r?\n/);
        }
        return this.lines[index];
    }
    positionAt(offset) {
        const pos = this._doc.positionAt(offset);
        return (0, position_1.makePosition)(pos.line, pos.character);
    }
    getText(range) {
        return this._doc.getText(range);
    }
}
exports.InMemoryDocument = InMemoryDocument;
