import { ILogger } from './logging';
import { IMdParser } from './parser';
import { Slug } from './slugify';
import { ILocation } from './types/location';
import { ITextDocument } from './types/textDocument';
import { IUri } from './types/uri';
import { Disposable } from './util/dispose';
import { IMdWorkspace } from './workspace';
export interface TocEntry {
    readonly slug: Slug;
    readonly text: string;
    readonly level: number;
    readonly line: number;
    /**
     * The entire range of the header section.
     *
    * For the doc:
     *
     * ```md
     * # Head #
     * text
     * # Next head #
     * ```
     *
     * This is the range from `# Head #` to `# Next head #`
     */
    readonly sectionLocation: ILocation;
    /**
     * The range of the header declaration.
     *
     * For the doc:
     *
     * ```md
     * # Head #
     * text
     * ```
     *
     * This is the range of `# Head #`
     */
    readonly headerLocation: ILocation;
    /**
     * The range of the header text.
     *
     * For the doc:
     *
     * ```md
     * # Head #
     * text
     * ```
     *
     * This is the range of `Head`
     */
    readonly headerTextLocation: ILocation;
}
export declare class TableOfContents {
    readonly entries: readonly TocEntry[];
    private readonly slugifier;
    static create(parser: IMdParser, document: ITextDocument): Promise<TableOfContents>;
    private static buildToc;
    private static getHeaderLevel;
    private static getHeaderText;
    static readonly empty: TableOfContents;
    private constructor();
    lookup(fragment: string): TocEntry | undefined;
}
export declare class MdTableOfContentsProvider extends Disposable {
    private readonly logger;
    private readonly _cache;
    constructor(parser: IMdParser, workspace: IMdWorkspace, logger: ILogger);
    get(resource: IUri): Promise<TableOfContents>;
    getForDocument(doc: ITextDocument): Promise<TableOfContents>;
}
